/* ppmtodat.c - scans a ppm for a plot and converts to plottable data pairs
**              
**
** Copyright (C) 1994 by Claus Schroeter.
**
** Permission to use, copy, modify, and distribute this software and its
** documentation for any purpose and without fee is hereby granted, provided
** that the above copyright notice appear in all copies and that both that
** copyright notice and this permission notice appear in supporting
** documentation.  This software is provided "as is" without express or
** implied warranty.
*/

#include "ppm.h"



#define COLOR(p) ((p.r) | (p.g)<<8 | (p.b)<<16)

void
main( argc, argv )
    int argc;
    char* argv[];
    {
    FILE* ifp;
    pixel ptab[256];
    pixel **ipixels, **opixels, bpixel;
    int cols, rows;
    int curves[100];
    int nc,nn;
    pixval maxval;
    int argn;
    int black;
    register int i,j,k ;

    long color,oldcolor;
    char* usage = 
	"[pbmfile]";

    ppm_init( &argc, argv );

    argn = 1;


    while ( argn < argc && argv[argn][0] == '-' && argv[argn][1] != '\0' )
	{

	if ( pm_keymatch( argv[argn], "-dim", 1) &&  argn + 1 < argc ) {
	    argn++;
#ifdef 0
	    if (sscanf(argv[argn], "%d", &dith_dim) != 1)
		pm_usage( usage );
#endif
	}

	else
	    pm_usage( usage );
	++argn;
	}


    if ( argn != argc )
	{
	ifp = pm_openr( argv[argn] );
	++argn;
	}
    else
	ifp = stdin;

    if ( argn != argc )
	pm_usage( usage );

    ipixels = ppm_readppm( ifp, &cols, &rows, &maxval );
    pm_close( ifp );
    opixels = ppm_allocarray(cols, rows);
    maxval = 255;


    /* first save background color assuming in first row,col */
    oldcolor = COLOR(ipixels[0][0]);
    black = 0;
    nc=0;

    for(i=0;i<cols;i++){
      nc = 0;
      for(j=0;j<rows;j++){
	/* color change detect */
	if(( COLOR(ipixels[j][i]))!=oldcolor ){
	  if( !black ) {
            /* test the pixel has at least two neighbours */
	    nn=0;
	    if( COLOR(ipixels[j-1][i]) != oldcolor ) nn++;
	    if( COLOR(ipixels[j+1][i]) != oldcolor ) nn++;
	    if( COLOR(ipixels[j][i-1]) != oldcolor ) nn++;
	    if( COLOR(ipixels[j][i+1]) != oldcolor ) nn++;

	    if( COLOR(ipixels[j-1][i+1]) != oldcolor ) nn++;
	    if( COLOR(ipixels[j-1][i-1]) != oldcolor ) nn++;
	    if( COLOR(ipixels[j+1][i+1]) != oldcolor ) nn++;
	    if( COLOR(ipixels[j+1][i-1]) != oldcolor ) nn++;


	    if( nn >= 2 ){
	      /* new curve detected */
	      curves[nc++] = rows - j;
	    }
	  }  
	  black = 1;
	} else
	  black = 0;
      }
      /* print data colums */
      if( nc > 0){
	printf("%d",i);
	for(k=0;k<nc;k++) printf("\t%d",curves[k]);
	printf("\n");
      }
    }
    exit(0);
}





